# Quick Reference

Objects Implemented:
- Manga
- Chapter
- Page

Requirements:
- aiohttp
- requests
- python >= 3.6

It has asynchronous support on practically everything! Check out the source here : https://repl.it/@thatonedev/mangadexpy

Better docs + Roadmap coming in v0.5.0

---

Questions? Comments? Feedback?
https://feedback.thatonedev.repl.co

---

Please note I will most likely not release any more updates until mangadex v4, which will have a more feature-rich api. But anyway, this lib can download a chapter fully, download an entire manga, or even index all the mangas on mangadex to create a bootleg search (what I am trying to do).

---

Get some examples here :
https://repl.it/@thatonedev/mangadex-examples